@@ -2,9 +2,8 @@ from dataclasses import dataclass, field
 from typing import List, Optional, Tuple
 
 from sqlfmt.comment import Comment
-from sqlfmt.exception import InlineCommentException
-from sqlfmt.node import Node
-from sqlfmt.token import Token
+from sqlfmt.node import Node, get_previous_token
+from sqlfmt.tokens import Token, TokenType
 
 
 @dataclass
@@ -85,7 +84,7 @@ class Line:
         proper indentation.
         """
         INDENT = " " * 4
-        prefix = INDENT * self.depth[0]
+        prefix = INDENT * (self.depth[0] + self.depth[1])
         return prefix
 
     def render_with_comments(self, max_length: int) -> str:
@@ -93,34 +92,26 @@ class Line:
         Returns a string that represents the properly-formatted Line,
         including associated comments
         """
-        content = str(self)
-        rendered = content
-        if len(self.comments) == 1:
-            # standalone or multiline comment
-            if self.nodes[0].is_newline:
-                rendered = f"{self.prefix}{self.comments[0]}"
-            # inline comment
+        content = str(self).rstrip()
+        rendered_lines: List[str] = []
+        inline_comments: List[str] = []
+        for comment in self.comments:
+            if comment.is_multiline or comment.is_standalone:
+                rendered_lines.append(
+                    comment.render_standalone(max_length=max_length, prefix=self.prefix)
+                )
             else:
-                try:
-                    comment = self.comments[0].render_inline(
-                        max_length=max_length, content_length=len(content.rstrip())
-                    )
-                    rendered = f"{content.rstrip()}{comment}"
-                except InlineCommentException:
-                    comment = self.comments[0].render_standalone(
-                        max_length=max_length, prefix=self.prefix
-                    )
-                    rendered = f"{comment}{content}"
-        # wrap comments above; note that str(comment) is newline-terminated
-        elif len(self.comments) > 1:
-            comment = "".join(
-                [
-                    c.render_standalone(max_length=max_length, prefix=self.prefix)
-                    for c in self.comments
-                ]
-            )
-            rendered = f"{comment}{content}"
-        return rendered
+                inline_comments.append(comment.render_inline())
+
+        if inline_comments:
+            rendered_lines.append(f"{content}{''.join(inline_comments)}\n")
+        # if content is empty AND we've already rendered a standalone or multiline
+        # comment, skip rendering the line itself, since that just adds a duplicate
+        # newline.
+        elif content or not self.comments:
+            rendered_lines.append(f"{self}")
+
+        return "".join(rendered_lines)
 
     @classmethod
     def from_nodes(
@@ -146,9 +137,11 @@ class Line:
                 previous_node=previous_node,
                 nodes=nodes,
                 comments=comments,
-                formatting_disabled=previous_node.formatting_disabled
-                if previous_node is not None
-                else [],
+                formatting_disabled=(
+                    previous_node.formatting_disabled
+                    if previous_node is not None
+                    else []
+                ),
             )
 
         return line
@@ -160,6 +153,14 @@ class Line:
             tokens.append(node.token)
         return tokens
 
+    @property
+    def previous_token_is_comma(self) -> bool:
+        token, _ = get_previous_token(self.previous_node)
+        if token is None:
+            return False
+        else:
+            return token.type is TokenType.COMMA
+
     @property
     def is_blank_line(self) -> bool:
         if (
