@@ -1,7 +1,7 @@
 from dataclasses import dataclass, field
 from typing import List, Optional, Tuple
 
-from sqlfmt.token import Token, TokenType
+from sqlfmt.tokens import Token, TokenType
 
 
 def get_previous_token(prev_node: Optional["Node"]) -> Tuple[Optional[Token], bool]:
@@ -200,9 +200,10 @@ class Node:
         if not prev_token:
             return False
         else:
-            return not (
-                prev_token.type
-                in (TokenType.UNTERM_KEYWORD, TokenType.COMMA, TokenType.DOT)
+            return prev_token.type not in (
+                TokenType.UNTERM_KEYWORD,
+                TokenType.COMMA,
+                TokenType.DOT,
             )
 
     @property
